# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`ibm_installation_manager`](#ibm_installation_manager): Init class for installing the IBM Installation Manager.

**Resource types**

* [`ibm_pkg`](#ibm_pkg): Custom type for installing an IBM package.

## Classes

### ibm_installation_manager

Init class for installing the IBM Installation Manager.

#### Examples

##### Installing Installation Manager to the default location of '/opt/IBM/InstallationManager'. In this example, we've downloaded and extracted the Installation Manager packages (installer) to '/vagrant/ibm/IM'

```puppet
class { 'ibm_installation_manager':
  source_dir => '/vagrant/ibm/IM',
}
```

##### Providing a zip source and a custom install location. This will retrieve the zip file from /mnt/IBM and extract it to /opt/IBM/tmp/InstallationManager. Installation Manager will then be installed to '/opt/myorg/InstallationManager'

```puppet
class { 'ibm_installation_manager':
 source     => '/mnt/IBM/im.zip',
 source_dir => '/opt/IBM/tmp/InstallationManager',
 target     => '/opt/myorg/InstallationManager',
}
```

#### Parameters

The following parameters are available in the `ibm_installation_manager` class.

##### `deploy_source`

Data type: `Any`

Specifies whether this module should be responsible for deploying the source package for Installation Manager.

Default value: `false`

##### `source`

Data type: `Any`

**Required** if `deploy_source` is true. Specifies the source. This can be either an absolute path to the source or an HTTP address. This expects a compressed archive from IBM (zip).

Default value: `undef`

##### `source_dir`

Data type: `Any`

Specifies the absolute path to the directory to deploy the installer from. (This is the directory containing the `installc` binary.) If you extracted the archive yourself, point this parameter to the extracted archive.

Default value: `undef`

##### `target`

Data type: `Any`

Specifies the absolute path to the base location where you want to install IBM Installation Manager. Set to `/opt/IBM/InstallationManager` as the default for the 'administrator' installation mode or '#{user_home}/IBM/InstallationManager' for 'nonadministrator' and 'group' installation modes.

Default value: `undef`

##### `manage_user`

Data type: `Any`

Whether or not to manage the user that will be installing the IBM Installation Manager.

Default value: `false`

##### `user`

Data type: `Any`

Specifies the user to run the installation as. Note that installing as a different user might cause undefined behavior. Consult IBM's documentation for details.
Note that installing as a user other than `root` might result in undefined behavior. Consult IBM's documentation for details. Installations by a non-root user won't share installation data with the rest of the system.

Default value: 'root'

##### `user_home`

Data type: `Any`

Specifies the home directory for the specified user. Required if you're using an installation_mode other than 'administrator'.

Default value: `undef`

##### `manage_group`

Data type: `Any`

When in 'group' mode, whether or not to manage the group that will be installing the IBM Installation Manager.

Default value: `false`

##### `group`

Data type: `Any`

Specifies the group to run the installation as. Note that installing as a user other than `root` might result in undefined behavior. Consult IBM's documentation for details. Installations by a non-root user won't share installation data with the rest of the system.

Default value: 'root'

##### `options`

Data type: `Any`

Specifies options to pass to the installer.
Default: - administrator mode: `-acceptLicense -s -log/tmp/IM_install.${timestamp}.log.xml -installationDirectory ${target}`. - nonadministrator/group mode: `-acceptLicense -accessRights nonAdmin -s -log /tmp/IM_install.${timestamp}.log.xml`

Default value: `undef`

##### `timeout`

Data type: `Any`

Specifies the timeout for the installation, in seconds. Installation Manager can take a long time to install, so if you have issues with Puppet timing out before the installation is complete, you might need to increase this parameter.

Default value: '900'

##### `installation_mode`

Data type: `Any`

Specifies which 'installation mode' you want to use to install the IBM Installation Manager. Values: 'administrator', 'nonadministrator', 'group'.

Default value: 'administrator'

## Resource types

### ibm_pkg

Custom type for installing an IBM package.

#### Properties

The following properties are available in the `ibm_pkg` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

#### Parameters

The following parameters are available in the `ibm_pkg` type.

##### `name`

namevar

An arbitrary name to identify the resource.

##### `jdk_package_name`

If a JDK must be installed separately (as in the case of Websphere Application Server 9), specify the package_name here (everything before the underscore in the IBM package name).

##### `jdk_package_version`

If a JDK must be installed separately (as in the case of Websphere Application Server 9), specify the version here.
Like 'version', this parameter refers to the number after the underscore in the IBM package name.

##### `imcl_path`

The full path to the imcl executable.
This is optional. The provider will attempt to locate imcl by parsing /<appDataLocation>/InstallationManager/installed.xml.
If, for some reason, it cannot be discovered or if you need to provide a specific path, you may do so with this parameter.

##### `target`

The full path to install the specified package to. Corresponds to the 'imcl' option '-installationDirectory'.

##### `package`

The IBM package name. Example: com.ibm.websphere.IBMJAVA.v71
This is the first part of the traditional IBM full package name, before the first underscore.

##### `repository`

The full path to the 'repository.config' file for installing this package.

##### `response`

Full path to an optional response file to use. The user is responsible for ensuring this file is present.

##### `version`

The version of the package. Example: 7.1.2000.20141116_0823
This is the second part of the traditional IBM full package name, after the first underscore.

##### `options`

Any custom options to pass to the 'imcl' tool for installing the package.

##### `user`

The user to run the 'imcl' command as.

Default value: root

##### `manage_ownership`

Valid values: `true`, `false`, yes, no

Whether or not to manage the ownership of installed packages. Allows for packages to not be installed as root.

Default value: `true`

##### `package_owner`

The user that should own this package installation. Only used if manage_ownership is true.

Default value: root

##### `package_group`

The group that should own this package installation. Only used if manage_ownership is true.

Default value: root

